function [I_to,I_sus,a_q,b_q,a_r,b_r] = update_I_4AP(con,V_m,q,r)
% 4-aminopyridine-sensitive currents (I 4AP =I to + I sus). The formulation
% of this current was taken from the Kurata model 2002.
%
% Joachim Behar, 04-05-2017
% Bioenergetics and Bioelectric Systems Lab
% Technion, Haifa, Israel
%
%
%    This program is free software; you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation; either version 2 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program; if not, write to the Free Software
%    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

I_to = con.C*con.g_to*(V_m-con.E_K)*q*r;
I_sus = con.C*con.g_sus*(V_m-con.E_K)*r;

q_inf = 1/(1+exp((V_m+49)/13));
r_inf = 1/(1+exp(-(V_m-19.3)/15));
tho_q = 39.102/(0.57*exp(-0.08*(V_m+44))+0.065*exp(0.1*(V_m+45.93)))+6.06;
tho_r = 14.40516/(1.037*exp(0.09*(V_m+30.61))+0.369*exp(-0.12*(V_m+23.84)))+2.75352;

a_q = q_inf/tho_q;
b_q = (1-q_inf)/tho_q;
a_r = r_inf/tho_r;
b_r = (1-r_inf)/tho_r;
end




