function [I_CaL,a_l,b_l,a_fl,b_fl,a_fCa,b_fCa,ac] = update_I_CaL(con,V_m,c,ac,d_L,f_L,f_Ca)
%  L-type Ca2+ current (I_CaL)
% "L" stands for long-lasting referring to the length of activation
%
% Joachim Behar, 04-05-2017
% Bioenergetics and Bioelectric Systems Lab
% Technion, Haifa, Israel
%
%
%    This program is free software; you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation; either version 2 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program; if not, write to the Free Software
%    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

% -20% decrease
b_CaL = -0.2152+1.6913.*ac.PKA.^10.0808./(0.8836.^10.0808+ac.PKA.^10.0808);

I_CaL = con.C.*con.g_CaL.*(b_CaL+1).*(V_m-con.E_CaL).*d_L.*f_L.*f_Ca;

alpha_dL = -0.02839*(V_m+35)/(exp(-(V_m+35)/2.5)-1)-0.0849*V_m/(exp(-V_m/4.8)-1);
if V_m~=5; beta_dL = 0.01143*(V_m-5)/(exp((V_m-5)/2.5)-1); else beta_dL=0.02858; end;
d_Linf = 1/(1+exp(-(V_m+13.5)/6));
f_Linf = 1/(1+exp((V_m+35)/7.3));
f_Cainf = con.K_mfCa/(con.K_mfCa+c.Ca_sub); 
tho_dL = 1/(alpha_dL+beta_dL);
tho_fL = 257.1*exp(-((V_m+32.5)/13.9)^2)+44.3;
tho_fCa = f_Cainf/con.alpha_fCa;

a_l = d_Linf/tho_dL;
b_l = (1-d_Linf)/tho_dL;
a_fl = f_Linf/tho_fL;
b_fl = (1-f_Linf)/tho_fL;
a_fCa = f_Cainf/tho_fCa;
b_fCa = (1-f_Cainf)/tho_fCa;
end












