function [I_Kr,a_paF,b_paF,a_paS,b_paS,a_pi,b_pi] = update_I_Kr(con,V_m,p_aF,p_aS,p_i)
% rapidly activating delayed rectifier K+ current (I_Kr)
% The formulation of this current was taken from the Kurata model 2002.
%
% Joachim Behar, 04-05-2017
% Bioenergetics and Bioelectric Systems Lab
% Technion, Haifa, Israel
%
%
%    This program is free software; you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation; either version 2 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program; if not, write to the Free Software
%    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

I_Kr = con.C*con.g_Kr*(V_m-con.E_K)*(0.6*p_aF + 0.4*p_aS)*p_i;

pa_inf = 1/(1+exp(-(V_m+23.2)/10.6));
pi_inf = 1/(1+exp((V_m+28.6)/17.1));

tho_paF = 0.84655354/(0.0372*exp(V_m/15.9)+0.00096*exp(-V_m/22.5));
tho_paS = 0.84655354/(0.0042*exp(V_m/17.0)+0.00015*exp(-V_m/21.6));
tho_pi = 1/(0.1*exp(-V_m/54.645)+0.656*exp(V_m/106.157));

a_paF = pa_inf/tho_paF;
b_paF = (1-pa_inf)/tho_paF;
a_paS = pa_inf/tho_paS;
b_paS = (1-pa_inf)/tho_paS;
a_pi = pi_inf/tho_pi;
b_pi = (1-pi_inf)/tho_pi;
end

