function [I_NCX] = update_I_NCX(con,V_m,c)
% Na + -Ca 2+ exchanger current (I NCX). 3 Na+ exhanged for one Ca2+
% The formulation of this current was taken from the Kurata model 2002.
%
% Joachim Behar, 04-05-2017
% Bioenergetics and Bioelectric Systems Lab
% Technion, Haifa, Israel
%
%
%    This program is free software; you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation; either version 2 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program; if not, write to the Free Software
%    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

do = 1+(con.Cao./con.K_co).*(1+exp(con.Q_co*V_m./con.E_T))+(con.Nao./con.K_1no)...
    .*(1+(con.Nao./con.K_2no).*(1+con.Nao./con.K_3no));

k_43 = con.Nai./(con.K_3ni+con.Nai);
k_41 = exp(-con.Q_n.*V_m./(2.*con.E_T));
k_34 = con.Nao./(con.K_3no+con.Nao);
k_21 = (con.Cao./con.K_co).*exp(con.Q_co.*V_m./con.E_T)./do;
k_23 = (con.Nao./con.K_1no).*(con.Nao./con.K_2no).*(1+con.Nao./con.K_3no)...
    *exp(-con.Q_n.*V_m./(2.*con.E_T))./do;
k_32 = exp(con.Q_n.*V_m./(2.*con.E_T));

x_1 = k_34.*k_41.*(k_23+k_21)+k_21.*k_32.*(k_43+k_41);

di = 1+(c.Ca_sub./con.K_ci).*(1+exp(-con.Q_ci.*V_m./con.E_T)+con.Nai./con.K_cni)+(con.Nai./con.K_1ni).*...
    (1+(con.Nai./con.K_2ni).*(1+con.Nai./con.K_3ni));

k_12 = (c.Ca_sub./con.K_ci).*exp(-con.Q_ci.*V_m./con.E_T)./di;
k_14 = (con.Nai./con.K_1ni).*(con.Nai./con.K_2ni).*(1+con.Nai./con.K_3ni).*exp(con.Q_n.*V_m./(2.*con.E_T))./di;

x_2 = k_43.*k_32.*(k_14+k_12)+k_41.*k_12.*(k_34+k_32);
x_3 = k_43.*k_14.*(k_23+k_21)+k_12.*k_23.*(k_43+k_41);
x_4 = k_34.*k_23.*(k_14+k_12)+k_21.*k_14.*(k_34+k_32);

I_NCX = con.C.*con.k_NCX.*(k_21.*x_2-k_12.*x_1)./(x_1+x_2+x_3+x_4);
end





















