function [I_st,a_qa,b_qa,a_qi,b_qi] = update_I_st(con,V_m,qa,qi)
% Sustained inward current (I_st)
% The formulation of this current was taken from the Kurata model 2002.
%
% Joachim Behar, 04-05-2017
% Bioenergetics and Bioelectric Systems Lab
% Technion, Haifa, Israel
%
%
%    This program is free software; you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation; either version 2 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program; if not, write to the Free Software
%    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

I_st = con.C*con.g_st*(V_m-con.E_st)*qa*qi;

qa_inf = 1/(1+exp(-(V_m+57)/5));
alpha_qa = 1/(0.15*exp(-V_m/11)+0.2*exp(-V_m/700)); 
beta_qa = 1/(16*exp(V_m/8)+15*exp(V_m/50));
tho_qa = 1/(alpha_qa+beta_qa);

alpha_qi = 1/(3100*exp(V_m/13)+700*exp(V_m/70));
beta_qi = 1/(95*exp(-V_m/10)+50*exp(-V_m/700))+0.000229/(1+exp(-V_m/5));
tho_qi = 6.65/(alpha_qi+beta_qi);
qi_inf = alpha_qi/(alpha_qi+beta_qi);

a_qa = qa_inf/tho_qa;
b_qa = (1-qa_inf)/tho_qa;
a_qi = qi_inf/tho_qi;
b_qi = (1-qi_inf)/tho_qi;
end






